from seam.types import AbstractWebhooks, AbstractSeam as Seam, Webhook
from typing import Optional, Any, List, Dict, Union


class Webhooks(AbstractWebhooks):
    seam: Seam

    def __init__(self, seam: Seam):
        self.seam = seam

    def create(self, *, url: str, event_types: Optional[List[str]] = None) -> Webhook:
        json_payload = {}

        if url is not None:
            json_payload["url"] = url
        if event_types is not None:
            json_payload["event_types"] = event_types

        res = self.seam.make_request("POST", "/webhooks/create", json=json_payload)

        return Webhook.from_dict(res["webhook"])

    def delete(self, *, webhook_id: str) -> None:
        json_payload = {}

        if webhook_id is not None:
            json_payload["webhook_id"] = webhook_id

        self.seam.make_request("POST", "/webhooks/delete", json=json_payload)

        return None

    def get(self, *, webhook_id: str) -> Webhook:
        json_payload = {}

        if webhook_id is not None:
            json_payload["webhook_id"] = webhook_id

        res = self.seam.make_request("POST", "/webhooks/get", json=json_payload)

        return Webhook.from_dict(res["webhook"])

    def list(
        self,
    ) -> List[Webhook]:
        json_payload = {}

        res = self.seam.make_request("POST", "/webhooks/list", json=json_payload)

        return [Webhook.from_dict(item) for item in res["webhooks"]]

    def update(self, *, webhook_id: str, event_types: List[str]) -> None:
        json_payload = {}

        if webhook_id is not None:
            json_payload["webhook_id"] = webhook_id
        if event_types is not None:
            json_payload["event_types"] = event_types

        self.seam.make_request("POST", "/webhooks/update", json=json_payload)

        return None



from seam.types import AbstractWorkspaces, AbstractSeam as Seam, Workspace
from typing import Optional, Any, List, Dict, Union


class Workspaces(AbstractWorkspaces):
    seam: Seam

    def __init__(self, seam: Seam):
        self.seam = seam

    def create(
        self,
        *,
        name: str,
        connect_partner_name: str,
        is_sandbox: Optional[bool] = None,
        webview_primary_button_color: Optional[str] = None,
        webview_logo_shape: Optional[str] = None
    ) -> Workspace:
        json_payload = {}

        if name is not None:
            json_payload["name"] = name
        if connect_partner_name is not None:
            json_payload["connect_partner_name"] = connect_partner_name
        if is_sandbox is not None:
            json_payload["is_sandbox"] = is_sandbox
        if webview_primary_button_color is not None:
            json_payload["webview_primary_button_color"] = webview_primary_button_color
        if webview_logo_shape is not None:
            json_payload["webview_logo_shape"] = webview_logo_shape

        res = self.seam.make_request("POST", "/workspaces/create", json=json_payload)

        return Workspace.from_dict(res["workspace"])

    def get(
        self,
    ) -> Workspace:
        json_payload = {}

        res = self.seam.make_request("POST", "/workspaces/get", json=json_payload)

        return Workspace.from_dict(res["workspace"])

    def list(
        self,
    ) -> List[Workspace]:
        json_payload = {}

        res = self.seam.make_request("POST", "/workspaces/list", json=json_payload)

        return [Workspace.from_dict(item) for item in res["workspaces"]]

    def reset_sandbox(
        self,
    ) -> None:
        json_payload = {}

        self.seam.make_request("POST", "/workspaces/reset_sandbox", json=json_payload)

        return None



from seam.types import (
    AbstractAcsCredentialPools,
    AbstractSeam as Seam,
    AcsCredentialPool,
)
from typing import Optional, Any, List, Dict, Union


class AcsCredentialPools(AbstractAcsCredentialPools):
    seam: Seam

    def __init__(self, seam: Seam):
        self.seam = seam

    def list(self, *, acs_system_id: str) -> List[AcsCredentialPool]:
        json_payload = {}

        if acs_system_id is not None:
            json_payload["acs_system_id"] = acs_system_id

        res = self.seam.make_request(
            "POST", "/acs/credential_pools/list", json=json_payload
        )

        return [
            AcsCredentialPool.from_dict(item) for item in res["acs_credential_pools"]
        ]



from seam.types import (
    AbstractAccessCodesSimulate,
    AbstractSeam as Seam,
    UnmanagedAccessCode,
)
from typing import Optional, Any, List, Dict, Union


class AccessCodesSimulate(AbstractAccessCodesSimulate):
    seam: Seam

    def __init__(self, seam: Seam):
        self.seam = seam

    def create_unmanaged_access_code(
        self, *, device_id: str, name: str, code: str
    ) -> UnmanagedAccessCode:
        json_payload = {}

        if device_id is not None:
            json_payload["device_id"] = device_id
        if name is not None:
            json_payload["name"] = name
        if code is not None:
            json_payload["code"] = code

        res = self.seam.make_request(
            "POST",
            "/access_codes/simulate/create_unmanaged_access_code",
            json=json_payload,
        )

        return UnmanagedAccessCode.from_dict(res["access_code"])



import os

from .routes import Routes
import requests
from importlib.metadata import version
from typing import Optional, Union, Dict, cast
from .types import AbstractSeam, SeamApiException


class Seam(AbstractSeam):
    """
    Initial Seam class used to interact with Seam API
    """

    api_key: str
    api_url: str = "https://connect.getseam.com"
    lts_version: str = "1.0.0"

    def __init__(
        self,
        api_key: Optional[str] = None,
        *,
        workspace_id: Optional[str] = None,
        api_url: Optional[str] = None,
        wait_for_action_attempt: Optional[Union[bool, Dict[str, float]]] = False,
    ):
        """
        Parameters
        ----------
        api_key : str, optional
          API key
        workspace_id : str, optional
          Workspace id
        api_url : str, optional
          API url
        """
        Routes.__init__(self)

        if api_key is None:
            api_key = os.environ.get("SEAM_API_KEY", None)
        if api_key is None:
            raise Exception(
                "SEAM_API_KEY not found in environment, and api_key not provided"
            )
        if workspace_id is None:
            workspace_id = os.environ.get("SEAM_WORKSPACE_ID", None)
        self.api_key = api_key
        self.workspace_id = workspace_id
        self.lts_version = Seam.lts_version
        self.wait_for_action_attempt = wait_for_action_attempt

        if os.environ.get("SEAM_API_URL", None) is not None:
            print(
                "\n"
                "\033[93m"
                "Using the SEAM_API_URL environment variable is deprecated. "
                "Support will be removed in a later major version. Use SEAM_ENDPOINT instead."
                "\033[0m"
            )
        api_url = (
            os.environ.get("SEAM_API_URL", None)
            or os.environ.get("SEAM_ENDPOINT", None)
            or api_url
        )
        if api_url is not None:
            self.api_url = cast(str, api_url)

    def make_request(self, method: str, path: str, **kwargs):
        """
        Makes a request to the API

        Parameters
        ----------
        method : str
          Request method
        path : str
          Request path
        **kwargs
          Keyword arguments passed to requests.request
        """

        url = self.api_url + path
        sdk_version = version("seam")
        headers = {
            "Authorization": "Bearer " + self.api_key,
            "Content-Type": "application/json",
            "User-Agent": "Python SDK v"
            + sdk_version
            + " (https://github.com/seamapi/python)",
            "seam-sdk-name": "seamapi/python",
            "seam-sdk-version": sdk_version,
            "seam-lts-version": self.lts_version,
        }
        if self.workspace_id is not None:
            headers["seam-workspace"] = self.workspace_id
        response = requests.request(method, url, headers=headers, **kwargs)

        if response.status_code != 200:
            raise SeamApiException(response)

        if "application/json" in response.headers["content-type"]:
            return response.json()

        return response.text



from seam.types import AbstractNoiseSensors, AbstractSeam as Seam
from typing import Optional, Any, List, Dict, Union
from seam.noise_sensors_noise_thresholds import NoiseSensorsNoiseThresholds
from seam.noise_sensors_simulate import NoiseSensorsSimulate


class NoiseSensors(AbstractNoiseSensors):
    seam: Seam

    def __init__(self, seam: Seam):
        self.seam = seam
        self._noise_thresholds = NoiseSensorsNoiseThresholds(seam=seam)
        self._simulate = NoiseSensorsSimulate(seam=seam)

    @property
    def noise_thresholds(self) -> NoiseSensorsNoiseThresholds:
        return self._noise_thresholds

    @property
    def simulate(self) -> NoiseSensorsSimulate:
        return self._simulate
